==> buffybox_3.2.0+dfsg.orig.tar.xz: buffybox-3.2.0/lvgl/tests/test_images/stride_align64/LZ4/test_I4_LZ4_align64.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif


#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_IMG_DUST
#define LV_ATTRIBUTE_IMG_DUST
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_IMG_DUST
uint8_t test_I4_LZ4_align64_map[] = {

    0x02,0x00,0x00,0x00,0x31,0x04,0x00,0x00,0x80,0x0b,0x00,0x00,0xff,0x32,0x4c,0x70,
    0x47,0x00,0x00,0x00,0x00,0xfc,0xff,0x00,0x00,0xfc,0x00,0xff,0xf0,0xfc,0x3e,0x8f,
    0x8f,0x35,0x00,0xff,0xff,0x98,0x00,0x00,0x00,0x8e,0x00,0xff,0xff,0x60,0x00,0xff,
    0xff,0xcc,0xff,0x00,0x00,0x97,0x06,0xff,0x08,0xff,0xd5,0xff,0x00,0xff,0xff,0xff,
    0xff,0xff,0x00,0xff,0x7f,0xff,0x77,0xff,0x00,0xff,0x00,0x00,0xff,0xff,0xaa,0x01,
    0x00,0x0f,0x27,0xa0,0x00,0x01,0x00,0x09,0x0d,0x00,0x0f,0x02,0x00,0x03,0x09,0x23,
    0x00,0x09,0x0d,0x00,0x0f,0x02,0x00,0x03,0x09,0x23,0x00,0xab,0xa0,0x01,0x11,0x11,
    0x11,0x1c,0xcc,0xcc,0xcc,0xc0,0x2d,0x00,0x11,0x0f,0xbb,0x00,0x3f,0xff,0xff,0xff,
    0x30,0x00,0x08,0x44,0x49,0x22,0x22,0x94,0x37,0x00,0x13,0x0f,0x09,0x00,0x1f,0x0f,
    0x30,0x00,0x07,0xe3,0x09,0x22,0x22,0x22,0x22,0x90,0x00,0x00,0x00,0x92,0x29,0x00,
    0x00,0x0f,0x61,0x00,0x0f,0x30,0x00,0x08,0xe2,0x92,0x22,0x22,0x22,0x22,0x29,0x00,
    0x00,0x00,0x22,0x22,0x00,0x00,0x0f,0x61,0x00,0x1f,0x0f,0x30,0x00,0x07,0x01,0x5f,
    0x00,0x01,0x61,0x00,0x02,0x30,0x00,0x01,0x61,0x00,0x0f,0x30,0x00,0x08,0x21,0x42,
    0x22,0x01,0x00,0x14,0x24,0x90,0x00,0x5f,0x0f,0x00,0x00,0x00,0x0f,0x30,0x00,0x08,
    0x01,0x8f,0x00,0x02,0x91,0x00,0x02,0x2a,0x00,0x3f,0x0f,0xff,0xff,0x30,0x00,0x09,
    0x01,0x5e,0x00,0x31,0x22,0x22,0x22,0x2f,0x00,0x52,0x00,0x0f,0x0f,0x0f,0x0f,0x05,
    0x00,0x0a,0x50,0x01,0xa1,0x0c,0xcc,0xcc,0xcc,0xc1,0x11,0x11,0x11,0x10,0x00,0x2d,
    0x00,0x81,0x22,0x22,0x22,0x00,0x04,0x92,0x29,0x40,0x2b,0x00,0x01,0x02,0x00,0x0b,
    0x50,0x01,0x0f,0x30,0x00,0x00,0x41,0x42,0x22,0x22,0x24,0x30,0x00,0x02,0x05,0x00,
    0x0f,0x60,0x00,0x0e,0x41,0x92,0x22,0x22,0x29,0x2b,0x00,0x0f,0xc0,0x00,0x01,0x06,
    0x60,0x00,0x05,0xf0,0x00,0x41,0x22,0x22,0x22,0x22,0x1a,0x01,0x0f,0x20,0x01,0x01,
    0x06,0x30,0x00,0x05,0x50,0x01,0x04,0x30,0x00,0x0f,0x80,0x01,0x02,0x06,0x30,0x00,
    0x05,0xb0,0x01,0x03,0x90,0x00,0x01,0x28,0x01,0x0f,0xf0,0x00,0x08,0x02,0x91,0x00,
    0x24,0x29,0x00,0xf0,0x00,0x01,0x9e,0x02,0x1f,0xff,0xf0,0x00,0x07,0x23,0x00,0x49,
    0x0f,0x02,0x02,0x50,0x01,0x01,0x5f,0x00,0x0e,0xa0,0x02,0x03,0x17,0x00,0x01,0x02,
    0x00,0x09,0xd0,0x02,0x02,0x5f,0x00,0x0d,0x00,0x03,0x01,0x29,0x00,0x0f,0x02,0x00,
    0x0a,0x0a,0x80,0x01,0x0f,0x2b,0x00,0x0a,0x01,0x02,0x00,0x0d,0x30,0x00,0x8f,0x04,
    0x44,0x00,0x00,0x00,0x00,0x01,0x11,0x01,0x00,0x03,0x0a,0x53,0x00,0x81,0xa0,0x00,
    0x04,0x61,0x11,0x11,0x16,0x60,0x4a,0x00,0x0f,0x02,0x00,0x03,0x0b,0x60,0x00,0x6f,
    0x61,0x11,0x11,0x11,0x11,0x16,0x2b,0x00,0x03,0x01,0x02,0x00,0x0b,0x30,0x00,0x02,
    0x86,0x00,0x0f,0x61,0x00,0x08,0x0d,0x30,0x00,0x51,0x40,0x04,0x11,0x11,0x14,0x4b,
    0x00,0x0f,0x02,0x00,0x02,0x0c,0x30,0x00,0x42,0x16,0x00,0x00,0x41,0x91,0x00,0x4e,
    0x06,0x61,0x11,0x64,0x33,0x00,0x0b,0x30,0x00,0x51,0x61,0x16,0x00,0x00,0x01,0x30,
    0x00,0x1f,0x04,0x99,0x00,0x03,0x0b,0x30,0x00,0x02,0x4c,0x01,0x8f,0x16,0x00,0x00,
    0x00,0x06,0x11,0x16,0x61,0x99,0x00,0x00,0x02,0x23,0x00,0x03,0x02,0x00,0x44,0xa0,
    0x00,0x00,0x46,0x21,0x01,0x31,0x06,0x11,0x40,0x9e,0x00,0x04,0x02,0x00,0x6c,0x01,
    0x01,0x00,0x10,0x00,0x10,0x80,0x01,0x02,0xa8,0x01,0x79,0x16,0x00,0x00,0x00,0x04,
    0x66,0x00,0x30,0x00,0x03,0x02,0x00,0x0b,0x60,0x00,0x51,0x11,0x11,0x11,0x66,0x61,
    0xc0,0x00,0x42,0x00,0x00,0x66,0x66,0x09,0x00,0x33,0x06,0x66,0x40,0x2d,0x00,0x0d,
    0x30,0x00,0x43,0x06,0x11,0x11,0x60,0xf0,0x00,0x24,0x00,0x61,0xba,0x01,0x09,0x60,
    0x01,0x0a,0x60,0x00,0x34,0x06,0x11,0x11,0x20,0x01,0x33,0x06,0x11,0x16,0x60,0x00,
    0x3f,0x16,0x06,0x16,0xc0,0x00,0x05,0x01,0x1b,0x01,0x02,0x80,0x01,0x51,0x01,0x11,
    0x60,0x00,0x61,0x1a,0x02,0x31,0x44,0x66,0x11,0x8b,0x00,0x01,0x02,0x00,0x0d,0x60,
    0x00,0x22,0x60,0x46,0xf0,0x00,0x15,0x41,0x20,0x01,0x2f,0x11,0x11,0x30,0x00,0x09,
    0x01,0x02,0x00,0xff,0x01,0x14,0x00,0x00,0x01,0x11,0x14,0x61,0x11,0x11,0x40,0x00,
    0x00,0x06,0x16,0x04,0x11,0x90,0x00,0x05,0x01,0xe5,0x00,0x11,0x61,0x61,0x00,0x11,
    0x06,0x39,0x00,0x76,0x10,0x00,0x00,0x06,0x11,0x66,0x11,0x21,0x01,0x0a,0x90,0x00,
    0x61,0x00,0x06,0x11,0x11,0x16,0x06,0x30,0x00,0xef,0x00,0x61,0x11,0x14,0x61,0x11,
    0x10,0x00,0x00,0x00,0x61,0x16,0x11,0x60,0xf0,0x00,0x04,0x04,0x5f,0x03,0x01,0x02,
    0x00,0x01,0x69,0x03,0x41,0x00,0x00,0x00,0x04,0x06,0x00,0x03,0x02,0x00,0x0b,0x60,
    0x00,0x03,0x16,0x00,0x0f,0x02,0x00,0x07,0x09,0x23,0x00,0xfd,0x11,0xa0,0x0b,0xbb,
    0xbb,0xee,0xee,0xee,0xaa,0xaa,0xaa,0xaa,0xdd,0xdd,0xdd,0x33,0x33,0x33,0x33,0x33,
    0x38,0x88,0x88,0x85,0x55,0x55,0x57,0x77,0x77,0x77,0x44,0x44,0x04,0xe0,0x01,0xff,
    0x10,0x0b,0xbb,0xbe,0xbe,0xee,0xea,0xea,0xaa,0xaa,0xad,0xad,0xdd,0xdd,0x3d,0x33,
    0x33,0x33,0x33,0x83,0x88,0x88,0x58,0x55,0x55,0x57,0x57,0x77,0x74,0x74,0x74,0x40,
    0x30,0x00,0x00,0x21,0xbb,0xee,0x30,0x00,0x53,0xda,0xdd,0xdd,0xd3,0xd3,0x60,0x00,
    0x9f,0x58,0x55,0x55,0x75,0x77,0x77,0x77,0x47,0x04,0x60,0x00,0x0c,0x01,0x30,0x00,
    0x11,0x83,0x90,0x00,0x2f,0x75,0x77,0x60,0x00,0x08,0x21,0xee,0xaa,0x90,0x00,0x11,
    0xd3,0x90,0x00,0x02,0x60,0x00,0x1f,0x57,0x60,0x00,0x09,0x22,0xae,0xae,0xf0,0x00,
    0x04,0x60,0x00,0x0f,0xc0,0x00,0x0d,0x62,0xee,0xaa,0xaa,0xaa,0xda,0xda,0x2f,0x00,
    0x03,0x20,0x01,0x0f,0xc0,0x00,0x0e,0x23,0xaa,0xdd,0x51,0x01,0x02,0x20,0x01,0x0f,
    0xc0,0x00,0x0a,0x04,0x20,0x01,0x04,0x80,0x01,0x0f,0xc0,0x00,0x0d,0x03,0xf0,0x00,
    0x05,0x60,0x00,0x1f,0x85,0x80,0x01,0x10,0x13,0xaa,0xef,0x00,0x03,0x20,0x01,0x0f,
    0xc0,0x00,0x0a,0x0c,0x60,0x00,0x02,0xb0,0x01,0x0f,0xe0,0x01,0x0f,0x04,0xc0,0x00,
    0x03,0x40,0x02,0x0f,0xe0,0x01,0x03,0x12,0xbb,0x60,0x00,0x24,0xaa,0xdd,0x91,0x00,
    0x01,0x60,0x00,0x01,0x40,0x02,0x1e,0x44,0x40,0x02,0x0f,0xc8,0x02,0x07,0x04,0x02,
    0x00,0x0a,0xd0,0x02,0x04,0x16,0x00,0x0f,0x02,0x00,0x07,0x0f,0x30,0x00,0x2a,0x0f,
    0x0f,0x0b,0x0f,0x14,0xaa,0x60,0x00,0x50,0x00,0x00,0x00,0x00,0x00,

};

const lv_img_dsc_t test_I4_LZ4_align64 = {
  .header.magic = LV_IMAGE_HEADER_MAGIC,
  .header.cf = LV_COLOR_FORMAT_I4,
  .header.flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
  .header.w = 71,
  .header.h = 60,
  .header.stride = 48,
  .data_size = 1085,
  .data = test_I4_LZ4_align64_map,
};

==> buffybox_3.4.2+dfsg.orig.tar.xz: buffybox-3.4.2+dfsg/lvgl/tests/test_images/stride_align64/LZ4/test_I4_LZ4_align64.c <==

#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_I4_LZ4_ALIGN64
#define LV_ATTRIBUTE_TEST_I4_LZ4_ALIGN64
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_I4_LZ4_ALIGN64
uint8_t test_I4_LZ4_align64_map[] = {

    0x02,0x00,0x00,0x00,0x31,0x04,0x00,0x00,0x80,0x0b,0x00,0x00,0xff,0x32,0x4c,0x70,
    0x47,0x00,0x00,0x00,0x00,0xfc,0xff,0x00,0x00,0xfc,0x00,0xff,0xf0,0xfc,0x3e,0x8f,
    0x8f,0x35,0x00,0xff,0xff,0x98,0x00,0x00,0x00,0x8e,0x00,0xff,0xff,0x60,0x00,0xff,
    0xff,0xcc,0xff,0x00,0x00,0x97,0x06,0xff,0x08,0xff,0xd5,0xff,0x00,0xff,0xff,0xff,
    0xff,0xff,0x00,0xff,0x7f,0xff,0x77,0xff,0x00,0xff,0x00,0x00,0xff,0xff,0xaa,0x01,
    0x00,0x0f,0x27,0xa0,0x00,0x01,0x00,0x09,0x0d,0x00,0x0f,0x02,0x00,0x03,0x09,0x23,
    0x00,0x09,0x0d,0x00,0x0f,0x02,0x00,0x03,0x09,0x23,0x00,0xab,0xa0,0x01,0x11,0x11,
    0x11,0x1c,0xcc,0xcc,0xcc,0xc0,0x2d,0x00,0x11,0x0f,0xbb,0x00,0x3f,0xff,0xff,0xff,
    0x30,0x00,0x08,0x44,0x49,0x22,0x22,0x94,0x37,0x00,0x13,0x0f,0x09,0x00,0x1f,0x0f,
    0x30,0x00,0x07,0xe3,0x09,0x22,0x22,0x22,0x22,0x90,0x00,0x00,0x00,0x92,0x29,0x00,
    0x00,0x0f,0x61,0x00,0x0f,0x30,0x00,0x08,0xe2,0x92,0x22,0x22,0x22,0x22,0x29,0x00,
    0x00,0x00,0x22,0x22,0x00,0x00,0x0f,0x61,0x00,0x1f,0x0f,0x30,0x00,0x07,0x01,0x5f,
    0x00,0x01,0x61,0x00,0x02,0x30,0x00,0x01,0x61,0x00,0x0f,0x30,0x00,0x08,0x21,0x42,
    0x22,0x01,0x00,0x14,0x24,0x90,0x00,0x5f,0x0f,0x00,0x00,0x00,0x0f,0x30,0x00,0x08,
    0x01,0x8f,0x00,0x02,0x91,0x00,0x02,0x2a,0x00,0x3f,0x0f,0xff,0xff,0x30,0x00,0x09,
    0x01,0x5e,0x00,0x31,0x22,0x22,0x22,0x2f,0x00,0x52,0x00,0x0f,0x0f,0x0f,0x0f,0x05,
    0x00,0x0a,0x50,0x01,0xa1,0x0c,0xcc,0xcc,0xcc,0xc1,0x11,0x11,0x11,0x10,0x00,0x2d,
    0x00,0x81,0x22,0x22,0x22,0x00,0x04,0x92,0x29,0x40,0x2b,0x00,0x01,0x02,0x00,0x0b,
    0x50,0x01,0x0f,0x30,0x00,0x00,0x41,0x42,0x22,0x22,0x24,0x30,0x00,0x02,0x05,0x00,
    0x0f,0x60,0x00,0x0e,0x41,0x92,0x22,0x22,0x29,0x2b,0x00,0x0f,0xc0,0x00,0x01,0x06,
    0x60,0x00,0x05,0xf0,0x00,0x41,0x22,0x22,0x22,0x22,0x1a,0x01,0x0f,0x20,0x01,0x01,
    0x06,0x30,0x00,0x05,0x50,0x01,0x04,0x30,0x00,0x0f,0x80,0x01,0x02,0x06,0x30,0x00,
    0x05,0xb0,0x01,0x03,0x90,0x00,0x01,0x28,0x01,0x0f,0xf0,0x00,0x08,0x02,0x91,0x00,
    0x24,0x29,0x00,0xf0,0x00,0x01,0x9e,0x02,0x1f,0xff,0xf0,0x00,0x07,0x23,0x00,0x49,
    0x0f,0x02,0x02,0x50,0x01,0x01,0x5f,0x00,0x0e,0xa0,0x02,0x03,0x17,0x00,0x01,0x02,
    0x00,0x09,0xd0,0x02,0x02,0x5f,0x00,0x0d,0x00,0x03,0x01,0x29,0x00,0x0f,0x02,0x00,
    0x0a,0x0a,0x80,0x01,0x0f,0x2b,0x00,0x0a,0x01,0x02,0x00,0x0d,0x30,0x00,0x8f,0x04,
    0x44,0x00,0x00,0x00,0x00,0x01,0x11,0x01,0x00,0x03,0x0a,0x53,0x00,0x81,0xa0,0x00,
    0x04,0x61,0x11,0x11,0x16,0x60,0x4a,0x00,0x0f,0x02,0x00,0x03,0x0b,0x60,0x00,0x6f,
    0x61,0x11,0x11,0x11,0x11,0x16,0x2b,0x00,0x03,0x01,0x02,0x00,0x0b,0x30,0x00,0x02,
    0x86,0x00,0x0f,0x61,0x00,0x08,0x0d,0x30,0x00,0x51,0x40,0x04,0x11,0x11,0x14,0x4b,
    0x00,0x0f,0x02,0x00,0x02,0x0c,0x30,0x00,0x42,0x16,0x00,0x00,0x41,0x91,0x00,0x4e,
    0x06,0x61,0x11,0x64,0x33,0x00,0x0b,0x30,0x00,0x51,0x61,0x16,0x00,0x00,0x01,0x30,
    0x00,0x1f,0x04,0x99,0x00,0x03,0x0b,0x30,0x00,0x02,0x4c,0x01,0x8f,0x16,0x00,0x00,
    0x00,0x06,0x11,0x16,0x61,0x99,0x00,0x00,0x02,0x23,0x00,0x03,0x02,0x00,0x44,0xa0,
    0x00,0x00,0x46,0x21,0x01,0x31,0x06,0x11,0x40,0x9e,0x00,0x04,0x02,0x00,0x6c,0x01,
    0x01,0x00,0x10,0x00,0x10,0x80,0x01,0x02,0xa8,0x01,0x79,0x16,0x00,0x00,0x00,0x04,
    0x66,0x00,0x30,0x00,0x03,0x02,0x00,0x0b,0x60,0x00,0x51,0x11,0x11,0x11,0x66,0x61,
    0xc0,0x00,0x42,0x00,0x00,0x66,0x66,0x09,0x00,0x33,0x06,0x66,0x40,0x2d,0x00,0x0d,
    0x30,0x00,0x43,0x06,0x11,0x11,0x60,0xf0,0x00,0x24,0x00,0x61,0xba,0x01,0x09,0x60,
    0x01,0x0a,0x60,0x00,0x34,0x06,0x11,0x11,0x20,0x01,0x33,0x06,0x11,0x16,0x60,0x00,
    0x3f,0x16,0x06,0x16,0xc0,0x00,0x05,0x01,0x1b,0x01,0x02,0x80,0x01,0x51,0x01,0x11,
    0x60,0x00,0x61,0x1a,0x02,0x31,0x44,0x66,0x11,0x8b,0x00,0x01,0x02,0x00,0x0d,0x60,
    0x00,0x22,0x60,0x46,0xf0,0x00,0x15,0x41,0x20,0x01,0x2f,0x11,0x11,0x30,0x00,0x09,
    0x01,0x02,0x00,0xff,0x01,0x14,0x00,0x00,0x01,0x11,0x14,0x61,0x11,0x11,0x40,0x00,
    0x00,0x06,0x16,0x04,0x11,0x90,0x00,0x05,0x01,0xe5,0x00,0x11,0x61,0x61,0x00,0x11,
    0x06,0x39,0x00,0x76,0x10,0x00,0x00,0x06,0x11,0x66,0x11,0x21,0x01,0x0a,0x90,0x00,
    0x61,0x00,0x06,0x11,0x11,0x16,0x06,0x30,0x00,0xef,0x00,0x61,0x11,0x14,0x61,0x11,
    0x10,0x00,0x00,0x00,0x61,0x16,0x11,0x60,0xf0,0x00,0x04,0x04,0x5f,0x03,0x01,0x02,
    0x00,0x01,0x69,0x03,0x41,0x00,0x00,0x00,0x04,0x06,0x00,0x03,0x02,0x00,0x0b,0x60,
    0x00,0x03,0x16,0x00,0x0f,0x02,0x00,0x07,0x09,0x23,0x00,0xfd,0x11,0xa0,0x0b,0xbb,
    0xbb,0xee,0xee,0xee,0xaa,0xaa,0xaa,0xaa,0xdd,0xdd,0xdd,0x33,0x33,0x33,0x33,0x33,
    0x38,0x88,0x88,0x85,0x55,0x55,0x57,0x77,0x77,0x77,0x44,0x44,0x04,0xe0,0x01,0xff,
    0x10,0x0b,0xbb,0xbe,0xbe,0xee,0xea,0xea,0xaa,0xaa,0xad,0xad,0xdd,0xdd,0x3d,0x33,
    0x33,0x33,0x33,0x83,0x88,0x88,0x58,0x55,0x55,0x57,0x57,0x77,0x74,0x74,0x74,0x40,
    0x30,0x00,0x00,0x21,0xbb,0xee,0x30,0x00,0x53,0xda,0xdd,0xdd,0xd3,0xd3,0x60,0x00,
    0x9f,0x58,0x55,0x55,0x75,0x77,0x77,0x77,0x47,0x04,0x60,0x00,0x0c,0x01,0x30,0x00,
    0x11,0x83,0x90,0x00,0x2f,0x75,0x77,0x60,0x00,0x08,0x21,0xee,0xaa,0x90,0x00,0x11,
    0xd3,0x90,0x00,0x02,0x60,0x00,0x1f,0x57,0x60,0x00,0x09,0x22,0xae,0xae,0xf0,0x00,
    0x04,0x60,0x00,0x0f,0xc0,0x00,0x0d,0x62,0xee,0xaa,0xaa,0xaa,0xda,0xda,0x2f,0x00,
    0x03,0x20,0x01,0x0f,0xc0,0x00,0x0e,0x23,0xaa,0xdd,0x51,0x01,0x02,0x20,0x01,0x0f,
    0xc0,0x00,0x0a,0x04,0x20,0x01,0x04,0x80,0x01,0x0f,0xc0,0x00,0x0d,0x03,0xf0,0x00,
    0x05,0x60,0x00,0x1f,0x85,0x80,0x01,0x10,0x13,0xaa,0xef,0x00,0x03,0x20,0x01,0x0f,
    0xc0,0x00,0x0a,0x0c,0x60,0x00,0x02,0xb0,0x01,0x0f,0xe0,0x01,0x0f,0x04,0xc0,0x00,
    0x03,0x40,0x02,0x0f,0xe0,0x01,0x03,0x12,0xbb,0x60,0x00,0x24,0xaa,0xdd,0x91,0x00,
    0x01,0x60,0x00,0x01,0x40,0x02,0x1e,0x44,0x40,0x02,0x0f,0xc8,0x02,0x07,0x04,0x02,
    0x00,0x0a,0xd0,0x02,0x04,0x16,0x00,0x0f,0x02,0x00,0x07,0x0f,0x30,0x00,0x2a,0x0f,
    0x0f,0x0b,0x0f,0x14,0xaa,0x60,0x00,0x50,0x00,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_I4_LZ4_align64 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_I4,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 48,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_I4_LZ4_align64_map),
  .data = test_I4_LZ4_align64_map,
  .reserved = NULL,
};
